#
# spec file for package kirigami-addons6
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.5.0
%define qt6_version 6.6.0

%bcond_without released

%define rname kirigami-addons
Name:           kirigami-addons6
Version:        1.7.0
Release:        1.2
Summary:        Add-ons for the Kirigami framework
License:        LGPL-3.0-only
URL:            https://invent.kde.org/libraries/kirigami-addons
Source:         https://download.kde.org/stable/%{rname}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/%{rname}/%{rname}-%{version}.tar.xz.sig
Source2:        kirigami-addons.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiPlatform) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       libKF6Svg6 >= %{kf6_version}
Requires:       libKirigamiAddonsStatefulApp6 >= %{version}
Requires:       qt6-qt5compat-imports >= %{qt6_version}

%description
A set of "widgets" i.e visual end user components along with a
code to support them. Components are usable by both touch and
desktop experiences providing a native experience on both, and
look native with any QQC2 style (qqc2-desktop-theme, Material
or Plasma).

%package -n libKirigamiAddonsStatefulApp6
Summary:        Stateful application suppport library for kirigami-addons

%description -n libKirigamiAddonsStatefulApp6
A set of "widgets" i.e visual end user components along with a
code to support them. Components are usable by both touch and
desktop experiences providing a native experience on both, and
look native with any QQC2 style (qqc2-desktop-theme, Material
or Plasma). This package provides a library to add standard
stateful functionality to applications using kirigami-addons.

%package devel
Summary:        Development files for kirigami-addons6
Requires:       kirigami-addons6 = %{version}
Requires:       libKirigamiAddonsStatefulApp6 >= %{version}

%description devel
A set of "widgets" i.e visual end user components along with a
code to support them. Components are usable by both touch and
desktop experiences providing a native experience on both, and
look native with any QQC2 style (qqc2-desktop-theme, Material
or Plasma). This package provides development files to build
applications with kirigami-addons.

%package lang
Summary:        Translations for package %{name}
Requires:       %{name} = %{version}
Provides:       %{name}-lang-all = %{version}
# Same file names, needs to be fixed upstream
Conflicts:      kirigami-addons-lang
BuildArch:      noarch

%description lang
Provides translations for %{name}.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
# A DBUILD_QCH option exists but does nothing
%cmake_kf6 -DBUILD_WITH_QT6:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%ldconfig_scriptlets -n libKirigamiAddonsStatefulApp6

%files
%license LICENSES/*
%{_kf6_qmldir}/org/kde/kirigamiaddons/

%files -n libKirigamiAddonsStatefulApp6
%{_kf6_libdir}/libKirigamiAddonsStatefulApp.so.*

%files devel
%{_kf6_cmakedir}/KF6KirigamiAddons/
%{_includedir}/KirigamiAddonsStatefulApp/
%{_kf6_libdir}/libKirigamiAddonsStatefulApp.so
%dir %{_kf6_sharedir}/kdevappwizard/
%dir %{_kf6_sharedir}/kdevappwizard/templates/
%{_kf6_sharedir}/kdevappwizard/templates/kirigamiaddons6.tar.bz2
%{_kf6_sharedir}/kdevappwizard/templates/librarymanager6.tar.bz2

%files lang -f %{name}.lang

%changelog
* Sun Jan 19 2025 Christophe Marin <christophe@krop.fr>
- Update to 1.7.0
  https://carlschwan.eu/2025/01/16/kirigami-addons-1.7.0/
  * New component: ConvergentContextMenu
  * Kirigami Addons’ shortcut editor can now be embedded in
    normal ConfigurationView via a new
    ConfigurationModule: ShortcutsConfigurationModule
  * The FormCardPage now uses a slighly less grey to get more
    contrasts with the sidebar
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.6.0
  https://carlschwan.eu/2024/11/30/kirigami-addons-1.6.0/
  * Improvements to AboutPage
  * New component: RadioSelector
  * New component: FormPlaceholderMessageDelegate
  * Fixed issues in DatePicker
* Fri Oct 11 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.5.0
  https://carlschwan.eu/2024/10/10/kirigami-addons-1.5/
  * New KAppTemplate’s template
  * Numerous changes to FormCard
  * The Banner component is now deprecated
* Wed Jul 24 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.4.0
  https://carlschwan.eu/2024/07/23/kirigami-addons-1.4/
  * New module to manage actions similar to that we can find in
    the QtWidgets world
  * The FormCard design was tweaked a bit more when using a dark
    theme
  * New component to the FormCard collection: FormTextAreaDelegate
* Wed Jun 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.3.0
  https://carlschwan.eu/2024/06/26/kirigami-addons-1.3.0/ for list
  of new features
  * Ensure all translated strings are loaded from the correct
    translation domain
  * The license dialog in the AboutPage is now opened in the
    correct window
  * Fix the focus in the FormComboBoxDelegate
  * Fix the capitalization in the AboutPage
  * Increase the padding in FormCardDialog to match the other
    FormCard components
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.2.1
  * Fix regression with double accept
  * Update maintainer name
  * Define minimum requirement on framework
* Fri May 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.2.0:
  https://carlschwan.eu/2024/05/09/kirigami-addons-1.2/
  * Accessibility fixes
  * New component: FloatingToolBar
* Tue Apr  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.1.0
  * New FormCard delegate: FormColorDelegate
  * New delegate container: FormCardDialog
  * Fixed a newline bug in the AboutKDE component
  * The default size of MessageDialog was decreased
  * Fixed the autoplay of the video delegate for the maximized
    album component
* Tue Mar  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.0.1
  * New feature release
  * For more details please see
    https://carlschwan.eu/2024/02/22/kirigami-addons-1.0/
- Changes since 0.11.90:
  * Bump version
  * Update example
  * DoubleFloatingButton: show tooltip
  * Initialize the AM/PM state correctly
  * Fix opening date time popup
  * Bump version to 1.0
  * Use RoundedItemDelegate in formcard
  * form date time: Add api to specify popup parent
  * Fix transparent seperator
  * fix __padding to make it possible to set radius to Infinity
  * make DoubleFloatingButton consistent with FloatingButton
  * Bind default property of FormCard to data
  * formcard: Reorganize layout of combobox delegate
  * Set border colors to match Breeze widget colors
  * Hide SegmentedButton implementation details from the a11y tree
  * Use Kirigami's OverlayZStacking for AbstractMaximizeComponent
  * Make time picker accessible
  * Hide implementation details from combo box and date time delegates for a11y
  * Improve accessibility of form swich delegates
  * Decrease size of delegate on mobile
  * Set a11y name rather than description on form text fields
  * Hide FormCheckDelegate implementation details from accessibility tree
  * Fix VideoMaximizeDelegate temp image size
- Move -lang conflicts to the -lang package
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 0.11.90
* Tue Oct 24 2023 Christophe Marin <christophe@krop.fr>
- Init kirigami-addons6
